## ----setup, include = FALSE---------------------------------------------------

knitr::opts_chunk$set(
  fig.path = "figures/",        
  dev = "png",                  
  dpi = 300,                     
  fig.width = 7,               
  fig.height = 4,               
  fig.align = "center",          
  out.width = "70%",           
  message = FALSE,              
  warning = FALSE               
)



## ----eval=FALSE---------------------------------------------------------------
# 
# #                         INSTALL CRAN PACKAGES
# 
# # Install missing CRAN packages
# install.packages(setdiff(
#   c(
#     "stats", "dplyr", "ggplot2", "flextable", "ggpubr",
#     "randomForest", "ggridges", "ggalluvial", "tibble",
#     "matrixStats", "RColorBrewer", "ape", "rlang",
#     "scales", "magrittr", "phangorn", "igraph", "tidyr",
#     "xml2", "data.table", "reshape2", "vegan", "patchwork", "officer"
#   ),
#   installed.packages()[, "Package"]
# ))
# 
# # Load CRAN packages
# lapply(c(
#   "stats", "dplyr", "ggplot2", "flextable", "ggpubr", "randomForest",
#   "ggridges", "ggalluvial", "tibble", "matrixStats", "RColorBrewer",
#   "ape", "rlang", "scales", "magrittr", "phangorn", "igraph", "tidyr",
#   "xml2", "data.table", "reshape2", "vegan", "patchwork", "officer"
# ), library, character.only = TRUE)
# 
# 
# #                         INSTALL BIOCONDUCTOR PACKAGES
# 
# 
# # Install BiocManager if not installed
# if (!requireNamespace("BiocManager", quietly = TRUE)) install.packages("BiocManager")
# 
# # Install missing Bioconductor packages
# BiocManager::install(setdiff(
#   c(
#     "phyloseq", "msa", "DESeq2", "ggtree", "edgeR",
#     "Biostrings", "DECIPHER", "microbiome", "limma",
#     "S4Vectors", "SummarizedExperiment", "TreeSummarizedExperiment"
#   ),
#   installed.packages()[, "Package"]
# ))
# 
# # Load Bioconductor packages
# lapply(
#   c(
#     "phyloseq", "msa", "DESeq2", "edgeR", "Biostrings", "ggtree", "DECIPHER",
#     "microbiome", "limma", "S4Vectors", "SummarizedExperiment", "TreeSummarizedExperiment"
#   ),
#   library,
#   character.only = TRUE
# )
# 
# 
# #                         INSTALL DspikeIn FROM GITHUB
# 
# 
# # To access the DspikeIn vignette for a detailed tutorial, use vignette("DspikeIn"), or browse all available vignettes with browseVignettes("DspikeIn").
# devtools::install_github("mghotbi/DspikeIn", build_vignettes = TRUE, dependencies = TRUE)
# library(DspikeIn)
# browseVignettes("DspikeIn")
# vignette("DspikeIn")
# 
# ## or
# 
# if (!requireNamespace("devtools", quietly = TRUE)) install.packages("devtools")
# devtools::install_github("mghotbi/DspikeIn")
# 
# # Load DspikeIn only if installed
# if ("DspikeIn" %in% installed.packages()[, "Package"]) {
#   library(DspikeIn)
# } else {
#   stop("DspikeIn installation failed. Check errors above.")
# }

## ----eval=FALSE---------------------------------------------------------------
# 
# #             To remove strain from the taxonomic ranks
# 
# # DspikeIn works with 7 taxonomic ranks
# # colnames(taxmat) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")
# 
# # Function to remove strain or bracketed info
# remove_strain_info <- function(df) {
#   pattern <- "Strain.*|strain.*|\\s*\\[.*?\\]|\\s*\\(.*?\\)"
#   for (col in colnames(df)) {
#     df[[col]] <- gsub(pattern, "", df[[col]])
#     df[[col]] <- trimws(df[[col]])}
#   return(df)}
# 
# # Apply to rowData of TSE
# taxonomy <- as.data.frame(rowData(tse_16SOTU))
# 
# # Clean strain
# cleaned_taxonomy <- remove_strain_info(taxonomy)
# 
# #  drop "Strain" if present
# if ("Strain" %in% colnames(cleaned_taxonomy)) {
#   cleaned_taxonomy <- cleaned_taxonomy[, colnames(cleaned_taxonomy) != "Strain"]}
# 
# # Re-assign to TSE
# rowData(tse_16SOTU) <- cleaned_taxonomy
# 
# 
# #             To add species rank to the taxonomic ranks
# 
# # Make sure 'Genus' exists
# if (!"Genus" %in% colnames(rowData(tse_16SOTU))) {
#   stop("The 'Genus' column is missing in rowData.")}
# 
# # prepare taxonomy
# taxonomy <- as.data.frame(rowData(tse_16SOTU))
# 
# # Handle missing genus labels
# taxonomy$Genus[is.na(taxonomy$Genus) | taxonomy$Genus == ""] <- "Unknown"
# taxonomy$Species <- paste0(taxonomy$Genus, "_OTU", seq_len(nrow(taxonomy)))
# 
# # Assign back to TSE
# rowData(tse_16SOTU) <- taxonomy
# 

## ----eval=FALSE---------------------------------------------------------------
# 
# 
# #                       Build TreeSummarizedExperiment (TSE)
# 
# 
# otu <- read.csv("otu.csv", header = TRUE, sep = ",", row.names = 1)
# otu_mat <- as.matrix(otu) # Convert to matrix
# tax <- read.csv("tax.csv", header = TRUE, sep = ",", row.names = 1)
# colnames(tax) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species")
# tax_mat <- as.matrix(tax) # Convert to matrix
# meta <- read.csv("metadata.csv", header = TRUE, sep = ",", row.names = 1)
# reference_seqs <- readDNAStringSet("dna-sequences.fasta", format = "fasta")
# tse <- TreeSummarizedExperiment(
#   assays = list(counts = otu_mat), # OTU table
#   rowData = tax_mat, # Taxonomy information
#   colData = meta, # Sample metadata
#   rowTree = MyTree, # Phylogenetic tree
#   rowSeqs = reference_seqs # Reference sequences)

## -----------------------------------------------------------------------------
# Use the Neighbor-Joining method  based on a Jukes-Cantor distance matrix and plot the tree with bootstrap values.
# we compare the Sanger read of Tetragenococcus halophilus with the FASTA sequence of Tetragenococcus halophilus from our phyloseq object.

library(Biostrings)
library(TreeSummarizedExperiment)
library(SummarizedExperiment)
library(DspikeIn)

# Get path to external data folder
extdata_path <- system.file("extdata", package = "DspikeIn")
list.files(extdata_path)

data("physeq_16SOTU", package = "DspikeIn")
tse_16SOTU<-convert_phyloseq_to_tse(physeq_16SOTU)
tse_16SOTU <- tidy_phyloseq_tse(tse_16SOTU)

# Filter TSE object to keep only Bacteria and Archaea

tse_16SOTU <- tse_16SOTU[
  rowData(tse_16SOTU)$Kingdom %in% c("Bacteria", "Archaea"),]


library(Biostrings)
# 
# # Subset the TSE object to include only Tetragenococcus
# tetragenococcus_tse <- tse_16SOTU[
#   rowData(tse_16SOTU)$Genus == "Tetragenococcus" &
#     !is.na(rownames(tse_16SOTU)) &
#     rownames(tse_16SOTU) != "", ]
# 
# ref_sequences <- referenceSeq(tetragenococcus_tse)
# 
# # Convert to DNAStringSet if needed
# ref_sequences <- Biostrings::DNAStringSet(ref_sequences)
# Biostrings::writeXStringSet(ref_sequences, filepath = "Sample.fasta")




ref_fasta <- system.file("extdata", "Ref.fasta", package = "DspikeIn")
sample_fasta <- system.file("extdata", "Sample.fasta", package = "DspikeIn")



result <- validate_spikein_clade(
  reference_fasta = ref_fasta,
  sample_fasta = sample_fasta,
  bootstrap = 200,
  output_prefix = NULL)

# result$tree_plot

## -----------------------------------------------------------------------------
#data("physeq_16SOTU", package = "DspikeIn")
tse_16SOTU
library(ggstar)
library(ggplot2)

# filter your object to only include spike-in taxa beforehand:
# change the OTU IDs for easy detection
# Big stars = detected in many samples
# Small stars = rarely detected
# log10(Mean Abundance) Bars= Color intensity reflects mean abundance.
# The log-transformed average abundance of each OTU across all samples where it appears.
# Extreme blue may signal unintended over-representation.
# Metadata Ring = factor of your interest e.g. Animal.type
# Each OTU is colored by where it was observed.
# Branch length numbers=	Actual evolutionary distances (small = very similar)


library(DspikeIn)
library(TreeSummarizedExperiment)

# ---- 1. Subset taxa where Genus is Tetragenococcus ----
spikein_tse <- tse_16SOTU[
  rowData(tse_16SOTU)$Genus == "Tetragenococcus", ]


# ---- 2. Diagnostic plot (tree-based) ----
ps <- plot_spikein_tree_diagnostic(
  obj = spikein_tse,
  metadata_var = "Animal.type",
  save_plot = FALSE )



## -----------------------------------------------------------------------------

#                      PREREQUISITE FOR 16S & CALCULATE SPIKED %


# Define spiked species and related parameters**

library(flextable)
library(DspikeIn)
library(TreeSummarizedExperiment)
library(SummarizedExperiment)
library(dplyr)

# Define spike-in parameters
spiked_cells <- 1847
species_name <- spiked_species <- c("Tetragenococcus_halophilus", "Tetragenococcus_sp.")

merged_spiked_species <- "Tetragenococcus"

# If you prefer Genus-level matching
# species_name <- spiked_species <- c("Tetragenococcus")
# merged_spiked_species <- "Tetragenococcus"



# --------------------------------------------
# Subset taxa for the spike-in species
tse_16SOTU_spiked_taxa <- tse_16SOTU[rowData(tse_16SOTU)$Species %in% species_name, ]

# (OTU) IDs
hashcodes <- rownames(tse_16SOTU_spiked_taxa)

# --------------------------------------------
# Subset samples based on spike-in volume (e.g., "1" or "2")
tse_16SOTU_spiked_samples <- tse_16SOTU[, colData(tse_16SOTU)$spiked.volume %in% c("2", "1") ]

# --------------------------------------------
# Merge spiked OTUs using the DspikeIn function
# merges monophyletic ASVs/OTUs

# The function Pre_processing_species() merges ASVs/OTUs
# of a species using "sum" or "max" methods, preserving taxonomic,
# phylogenetic, and sequencing data.



library(DspikeIn)
library(TreeSummarizedExperiment)
library(SummarizedExperiment)
output_rds <- file.path(tempdir(), "merged_tse_sum.rds")

Spiked_16S_sum_scaled <- Pre_processing_species(
  tse_16SOTU_spiked_samples,
  species_name,
  merge_method = "sum",
  output_file = output_rds)

# --------------------------------------------
# Calculate spike-in recovery percentage
Perc <- calculate_spike_percentage(
  Spiked_16S_sum_scaled,
  merged_spiked_species,
  passed_range = c(0.1, 20))


## ----eval=FALSE---------------------------------------------------------------
# 
# #                      PREREQUISITE FOR ITS & CALCULATE SPIKED %
# 
# 
# # Define spiked species and related parameters**
# 
# 
# # Define the spiked species
# # spiked_cells <- 733
# # species_name <- spiked_species <- merged_spiked_species <- "Dekkera_bruxellensis"
# 
# # Subset taxa for spiked species
# # Dekkera <- phyloseq::subset_taxa(
# # physeq_ITSOTU,
# # Species %in% species_name)
# 
# # hashcodes <- row.names(phyloseq::tax_table(Dekkera))
# 
# # Subset samples based on spiked volume
# # physeq_ITSOTU_spiked <- phyloseq::subset_samples(physeq_ITSOTU, spiked.volume %in% c("2", "1"))
# 
# # if TSE format
# # tse_ITSOTU <- convert_phyloseq_to_tse(physeq_ITSOTU)
# # physeq_ITSOTU_spiked <- tse_ITSOTU[, tse_ITSOTU$spiked.volume %in% c("2", "1")]

## -----------------------------------------------------------------------------

#                      CALCULATE SCALING FACTORS

result <- calculate_spikeIn_factors(
  Spiked_16S_sum_scaled,
  spiked_cells = spiked_cells,
  merged_spiked_species = species_name)

# View extracted outputs
result$spiked_species_reads # Merged spiked species name
result$total_reads # Total reads detected for the spike
scaling_factors <- result$scaling_factors
head(scaling_factors) # Vector of scaling factors per sample

## -----------------------------------------------------------------------------


#             Convert relative counts to absolute counts


# absolute counts=relative counts×sample-specific scaling factor

# Convert to absolute counts
library(DspikeIn)
absolute <- convert_to_absolute_counts(Spiked_16S_sum_scaled, scaling_factors)

# Extract processed data
absolute_counts <- absolute$absolute_counts
tse_absolute <- absolute$obj_adj

tse_absolute <- tidy_phyloseq_tse(tse_absolute)

# View absolute count data
head(tse_absolute)

## -----------------------------------------------------------------------------


#                      CALCULATE SPIKE PERCENTAGE & summary stat

# ** Calculate spike percentage & Generate summary statistics for absolute counts**

# Generate summary statistics for absolute counts
post_eval_summary <- calculate_summary_stats_table(absolute_counts)

# You may want to Back normal to check calculation accuracy
# the scaling factor was computed based on spiked species reads and fixed cell count.
# Multiplying the spiked species read count by this scaling factor restores the exact spiked cell count.
# lets check it
# BackNormal <- calculate_spike_percentage(
#  tse_absolute,
#  merged_spiked_species,
#  passed_range = c(0.1, 20)
# )

## -----------------------------------------------------------------------------
# The acceptable range of spiked species retrieval is system-dependent
# Spiked species become centroid of the community (Distance to Centroid)
# Spiked species become dominant and imbalance the community (Evenness)

# What range of spiked species retrieval is appropriate for your system?
# Calculate Pielou's Evenness using Shannon index and species richness (Observed)
# Hill number q = 1 = exp(Shannon index), representing the effective number of equally abundant species. Hill is weighted by relative abundance, so dominant species have more influence.
# Unlike Pielou's evenness, this metric is not normalized by richness and it shows Effective number of common species

library(TreeSummarizedExperiment)
library(SummarizedExperiment)
library(dplyr)
library(tibble)
library(microbiome)
library(mia)
library(vegan)
library(S4Vectors)
library(ggplot2)


# --- 1. Extract current metadata from TSE ---
metadata <- colData(tse_absolute) %>%
  as.data.frame() %>%
  rownames_to_column("Sample")

# --- 2. Add spike-in reads (Perc) ---
# Ensure Perc has 'Sample' column and matching format
metadata <- dplyr::left_join(metadata, Perc, by = "Sample")

# --- 3. Estimate alpha diversity indices and extract ---
tse_absolute <- mia::addAlpha(
  tse_absolute,
  index = c("observed", "shannon", "pielou", "hill")
)

alpha_df <- colData(tse_absolute) %>%
  as.data.frame() %>%
  rownames_to_column("Sample") %>%
  select(Sample, observed, shannon, pielou, hill)

metadata <- dplyr::left_join(metadata, alpha_df, by = "Sample")

# --- 4. Compute Bray-Curtis distance to centroid ---
otu_mat <- assay(tse_absolute, "counts")
otu_mat <- t(otu_mat)  # samples as rows
otu_mat_rel <- vegan::decostand(otu_mat, method = "total")

centroid_profile <- colMeans(otu_mat_rel)

dist_to_centroid <- apply(otu_mat_rel, 1, function(x) {
  vegan::vegdist(rbind(x, centroid_profile), method = "bray")[1]
})

# Match and assign distances
metadata$Dist_to_Centroid <- dist_to_centroid[metadata$Sample]

# --- 5. Assign updated metadata to TSE ---
metadata <- column_to_rownames(metadata, var = "Sample")
metadata <- metadata[colnames(tse_absolute), , drop = FALSE]  # ensure correct order and size

colData(tse_absolute) <- S4Vectors::DataFrame(metadata)


# 4. Regression Plots: Diversity vs. Spike-in Reads
# ============================================================================

# Pielou’s Evenness
plot_object_pielou <- regression_plot(
  data = metadata,
  x_var = "pielou",
  y_var = "Spiked_Reads",
  custom_range = c(0.1, 20, 30, 40, 50, 60, 100),
  plot_title = "Pielou’s Evenness vs. Spike-in Reads"
)

# Hill Number (q = 1)
plot_object_hill <- regression_plot(
  data = metadata,
  x_var = "hill",
  y_var = "Spiked_Reads",
  custom_range = c(0.1, 10, 20, 30, 100),
  plot_title = "Hill Number (q = 1) vs. Spike-in Reads"
)

# Distance to Centroid
plot_object_centroid <- regression_plot(
  data = metadata,
  x_var = "Dist_to_Centroid",
  y_var = "Spiked_Reads",
  custom_range = c(0.1, 20, 30, 40, 50, 60, 100),
  plot_title = "Distance to Global Centroid vs. Spike-in Reads"
)


# Interpretation
# ============================================================================
# - Pielou's evenness is normalized by richness; useful for detecting imbalance.
# - Hill number q = 1 gives effective number of common species; sensitive to dominance.
# - Distance to centroid in full Bray-Curtis space shows deviation from the average community.


## -----------------------------------------------------------------------------
# * Calculate the percentage of spiked species retrieval per sample*

library(mia)         
library(dplyr)
library(SummarizedExperiment)

# Subset TSE to remove blanks 
tse_absolute_filtered <- tse_absolute[, colData(tse_absolute)$sample.or.blank != "blank"]

# Calculate spike-in retrieval percentage
result_perc <- calculate_spike_percentage(
  tse_absolute_filtered,
  merged_spiked_species,
  passed_range = c(0.1, 20)
)

# Generate conclusion report
conc <- conclusion(
  tse_absolute_filtered,
  merged_spiked_species,
  max_passed_range = 20,
  output_path = output_path)

conc$full_report

# Filter to keep only the samples that passed
passed_samples <- result_perc$Sample[result_perc$Result == "passed"]

# Subset the TSE object to include only passed samples
tse_passed <- tse_absolute_filtered[, colnames(tse_absolute_filtered) %in% passed_samples]
dim(tse_passed)


## -----------------------------------------------------------------------------
# you may need to normalize/transform your data to reduce biases

ps <- tse_16SOTU

# TC Normalization
result_TC <- normalization_set(ps, method = "TC", groups = "Host.species")
normalized_ps_TC <- result_TC$dat.normed
scaling_factors_TC <- result_TC$scaling.factor

# UQ Normalization
result_UQ <- normalization_set(ps, method = "UQ", groups = "Host.species")
normalized_ps_UQ <- result_UQ$dat.normed
scaling_factors_UQ <- result_UQ$scaling.factor

# Median Normalization
result_med <- normalization_set(ps, method = "med", groups = "Host.species")
normalized_ps_med <- result_med$dat.normed
scaling_factors_med <- result_med$scaling.factor

# DESeq Normalization
ps_n <- remove_zero_negative_count_samples(ps)
result_DESeq <- normalization_set(ps_n, method = "DESeq", groups = "Animal.type")
normalized_ps_DESeq <- result_DESeq$dat.normed
scaling_factors_DESeq <- result_DESeq$scaling.factor

# Poisson Normalization
result_Poisson <- normalization_set(ps, method = "Poisson", groups = "Host.genus")
normalized_ps_Poisson <- result_Poisson$dat.normed
scaling_factors_Poisson <- result_Poisson$scaling.factor

# Quantile Normalization
result_QN <- normalization_set(ps, method = "QN")
normalized_ps_QN <- result_QN$dat.normed
scaling_factors_QN <- result_QN$scaling.factor

# TMM Normalization
result_TMM <- normalization_set(ps, method = "TMM", groups = "Animal.type")
normalized_ps_TMM <- result_TMM$dat.normed
scaling_factors_TMM <- result_TMM$scaling.factor

# CLR Normalization
result_clr <- normalization_set(ps, method = "clr")
normalized_ps_clr <- result_clr$dat.normed
scaling_factors_clr <- result_clr$scaling.factor

# Rarefying
result_rar <- normalization_set(ps, method = "rar")
normalized_ps_rar <- result_rar$dat.normed
scaling_factors_rar <- result_rar$scaling.factor

# CSS Normalization
result_css <- normalization_set(ps, method = "css")
normalized_ps_css <- result_css$dat.normed
scaling_factors_css <- result_css$scaling.factor

# TSS Normalization
result_tss <- normalization_set(ps, method = "tss")
normalized_ps_tss <- result_tss$dat.normed
scaling_factors_tss <- result_tss$scaling.factor

# RLE Normalization
result_rle <- normalization_set(ps, method = "rle")
normalized_ps_rle <- result_rle$dat.normed
scaling_factors_rle <- result_rle$scaling.factor


## -----------------------------------------------------------------------------
sessionInfo()

## ----cleanup, include = FALSE-------------------------------------------------
# =====================================================================
# FINAL CLEANUP: Remove files created during vignette execution
# =====================================================================

# **Note:** To comply with CRAN policies, this vignette removes any output files
# (e.g., plots, summary tables) created during execution.
# You may modify paths locally if you'd like to keep the outputs.

# List of all files possibly written by example functions
files_to_delete <- c(
  "Global_Network_Metrics.csv", "absolute_counts.csv",  "merged_physeq_processed.rds",
  "abundance_analysis_filtered_phyloseq.rds", "abundance_analysis_filtered_tse.rds",
  "abundance_analysis_high_abundance_phyloseq.rds", "abundance_analysis_high_abundance_tse.rds",
  "abundance_analysis_low_abundance_phyloseq.rds", "abundance_analysis_low_abundance_tse.rds",
  "adjusted_prevalence.rds", "core_microbiome.csv", "core_microbiome.rds", "comp_spikein_patristic_distances.csv", "comp_spikein_branch_lengths.pdf", "comp_spikein_patristic_distances_hist.pdf",
  "merged_data.csv", "merged_data.docx", "comp_spikein.nwk", "comp_spikein_tree.png", "comp_spikein_patristic_distances_hist.pfd","post_eval_summary.csv","post_eval_summary.docx",
  "merged_physeq_max_processed.rds", "merged_physeq_sum.rds",
  "merged_physeq_sum_processed.rds", "spikeIn_factors_output",
  "plot_Spike.percentage_Kruskal.pdf", "plot_Spike.percentage_Kruskal.png",
  "plot_Spike.reads_Kruskal.pdf", "plot_Spike.reads_Kruskal.png",
  "plot_Total.reads_Kruskal.pdf", "plot_Total.reads_Kruskal.png",
  "proportion_adjusted_physeq.rds", "proportion_adjusted_tse.rds",
  "randomsubsample_Trimmed_evenDepth.rds", "summary.csv", "summary.docx", "DspikeIn-manual.tex", "output.csv", "output.docx",
  "tree_with_bootstrap_and_cophenetic.png"
)

# Remove files safely
invisible(file.remove(files_to_delete[file.exists(files_to_delete)]))

# Remove known folders (if created by functions)
folders_to_delete <- c("spikeIn_factors_output")
for (folder in folders_to_delete) {
  if (dir.exists(folder)) {
    unlink(folder, recursive = TRUE, force = TRUE)
  }
}

